==> kita-0.102.1.tar.gz: kita-0.102.1/kita/src/kitaboardview.h <==
/***************************************************************************
*   Copyright (C) 2003 by Hideki Ikemoto                                  *
*   ikemo@users.sourceforge.jp                                            *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

#ifndef _KITABOARDVIEW_H_
#define _KITABOARDVIEW_H_

#include <qwidget.h>

#include "kitaboardviewbase.h"

class KURL;
class KListViewItem;

namespace Kita
{
    class Board;
    class Category;
}

/**
 *
 * @author Hideki Ikemoto <ikemo@users.sourceforge.jp>
 **/
class KitaBoardView : public KitaBoardViewBase
{
    Q_OBJECT
    KListViewItem* m_favorites;

    QString getCategory( const QString& line ) const;
    Kita::Board* getBoard( const QString& line ) const;
    bool isBoardUrl( const KURL& url ) const;
    QPtrList<Kita::Category> getCategoryList( const QString& html ) const;
    void refreshFavoriteBoards();

private slots:
    void loadBoard( QListViewItem* item );
    void slotContextMenuRequested( QListViewItem*, const QPoint&, int );

public:
    KitaBoardView( QWidget *parent, const char *name = 0 );
    ~KitaBoardView();

public slots:
    void loadBoardList();
    void setFont( const QFont& font );

signals:
    void clicked( const Kita::Board* board );
    void openBoardRequested( const Kita::Board* board, bool withNewTab = false );
};

#endif

==> kita-0.120.0.tar.gz: kita-0.120.0/kita/src/kitaboardview.h <==
/***************************************************************************
*   Copyright (C) 2003 by Hideki Ikemoto                                  *
*   ikemo@users.sourceforge.jp                                            *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
***************************************************************************/

#ifndef _KITABOARDVIEW_H_
#define _KITABOARDVIEW_H_

#include <qwidget.h>

#include "kitaboardviewbase.h"

class KURL;
class KListViewItem;

namespace Kita
{
    class Board;
    class Category;
}

/**
 *
 * @author Hideki Ikemoto <ikemo@users.sourceforge.jp>
 **/
class KitaBoardView : public KitaBoardViewBase
{
    Q_OBJECT
    KListViewItem* m_favorites;

    QString getCategory( const QString& line ) const;
    Kita::Board* getBoard( const QString& line ) const;
    bool isBoardUrl( const QString& url ) const;
    QPtrList<Kita::Category> getCategoryList( const QString& html ) const;
    void refreshFavoriteBoards();

private slots:
    void loadBoard( QListViewItem* item );
    void slotContextMenuRequested( QListViewItem*, const QPoint&, int );
    void slotMouseButtonClicked( int, QListViewItem* );

public:
    KitaBoardView( QWidget *parent, const char *name = 0 );
    ~KitaBoardView();

public slots:
    void loadBoardList();
    void setFont( const QFont& font );

signals:
    void openBoardRequested( const QString& boardURL, bool withNewTab = false );
};

#endif
